#!/bin/bash
= () 
{ 
    local in="$(echo "$@" | sed -e 's/\[/(/g' -e 's/\]/)/g')";
    awk 'BEGIN {print '"$in"'}' < /dev/null
}


while [ $# -gt 0 ]; do

    pdb=$1
    if [ ! -e $pdb ] ;then
	echo "NO such file $pdb. Continue ..."
	continue
    fi

    size="200,200"
    nrot=20
    delay=20
    pymol=/opt/local/bin/pymol
    mol=${pdb%%.pdb}
    echo -n "Doing $mol ..."
    
# maximum distance
    rm -f maxdist.xvg
    echo 0 0 | \
	g_mindist -f $mol.pdb -s $mol.pdb -max \
	-od maxdist.xvg \
	>& err || { cat err >&2; exit 1; }
    maxdist=$(tail -1 maxdist.xvg | awk '{printf "%.1f\n", $2*10*0.7}')
    
    cat <<EOF > frame.pml
reini
load PDB
bg_color white
show spheres
set sphere_scale, 0.3
show sticks
cmd.color("grey50","all")
color green,(name CL)
color green,(name Cl*)  
color blue,(name I*) 
util.cnc("all",_self=cmd)
zoom center, $maxdist
ray $size
cmd.png("PNG", prior=1)
EOF
    
    rm -f center.gro tmp.gro
    editconf -f $pdb -o tmp.gro -center 0 0 0 >& err || { cat err >&2; exit 1; }
    echo 0 | editconf -f tmp.gro -princ -o center.gro >& err \
	|| { cat err >&2; exit 1; }
    
    dphi=$(= "360/($nrot-1)")
    rm -f rot[0-9]*.pdb movie.pml
    # rotate around x
    j=0
    for ((i=0; i<nrot; i++)); do
	nr=$(printf "%04d\n" $j)
	phi=$(= "$dphi*$i")
	editconf -f center.gro -rotate $phi 0 0 -o rot$nr.pdb \
	    >& err || { cat err >&2; exit 1; }
	sed -e "s/PDB/rot$nr.pdb/" -e "s/PNG/frame$nr.png/" < frame.pml \
	    >> movie.pml
	let j++
    done    
    sed -e "s/PDB/rot$nr.pdb/" -e "s/PNG/frame${nr}_2.png/" < frame.pml \
	>> movie.pml

    # rotate around y
    for ((i=0; i<nrot; i++)); do
	nr=$(printf "%04d\n" $j)
	phi=$(= "$dphi*$i")
	editconf -f center.gro -rotate 0 $phi 0 -o rot$nr.pdb \
	    >& err || { cat err >&2; exit 1; }
	sed -e "s/PDB/rot$nr.pdb/" -e "s/PNG/frame$nr.png/" < frame.pml \
	    >> movie.pml
	let j++
    done
    sed -e "s/PDB/rot$nr.pdb/" -e "s/PNG/frame${nr}_2.png/" < frame.pml \
	>> movie.pml

    # rotate around z
    for ((i=0; i<nrot; i++)); do
	nr=$(printf "%04d\n" $j)
	phi=$(= "$dphi*$i")
	editconf -f center.gro -rotate 0 0 $phi -o rot$nr.pdb \
	    >& err || { cat err >&2; exit 1; }
	sed -e "s/PDB/rot$nr.pdb/" -e "s/PNG/frame$nr.png/" < frame.pml \
	    >> movie.pml
	let j++
    done
    sed -e "s/PDB/rot$nr.pdb/" -e "s/PNG/frame${nr}_2.png/" < frame.pml \
	>> movie.pml

    rm -f frame*png
    $pymol -qc movie.pml >& err || { cat err >&2; exit 1; }    
    convert -delay $delay -loop 0 frame*png $mol.gif
    echo "Created $mol.gif"
    
    rm -f frame*png rot*.pdb movie.pml center.gro tmp.gro maxdist.xvg err
    rm -f frame.pml
    shift
done



